package Parse::RecDescent::FAQ;

use vars qw($VERSION);

$VERSION = '7.1';

1;

__END__


=head1 NAME

Parse::RecDescent::FAQ - the official, authorized FAQ for Parse::RecDescent. 

=head1 DESCRIPTION

L<Parse::RecDescent::FAQ> is a document that I grew over the ages.
You can see that original document (still useful) at L<Parse::RecDescent::FAQ::Original>.

As it stands, I no longer have time for editing and categorizing
other people's posts to fit them into POD format
and to collect answers.

But I still scan Google alerts for new recdescent posts daily.

You may read the wheat that I have separated from the chaff via
my tagged L<delicious bookmarks|http://delicious.com/metaperl/parse-recdescent>.

You will also find the L<mailing list|http://lists.perl.org/list/recdescent.html> archives 
to be of some help.

=head1 AUTHOR

Terrence Brannon

=head1 REPO

The repo is on L<github|http://github.com/metaperl/Parse--RecDescent--FAQ>

